function opts = checkOptions_tv(opts)
%CHECKOPTION Checks the input arguments for pdNCG_tv.

%%
if ~isfield(opts, {'n1'})  
    error('The number vertical pixels n1 of the image is not provided.');
end    
if ~isfield(opts, {'n2'})  
    error('The number horizontal pixels n2 of the image n2 is not provided.');
end   
opts.n = opts.n1*opts.n2;
  
%%
if ~isfield(opts, {'A'})
    error('The measurement matrix opts.A is required.');
else
    if ~isa(opts.A, 'A_operator') && ~(sum(size(opts.A) > 1) == 2)
        error('The argument opts.A must be a matrix or of type "A_operator which operates on vectors or a MATLAB matrix".');
    end 
end
  
%%
if ~isfield(opts, {'b'})    
    error('Measurements vector b for the Least-Squares fidelity term is required.');
end

%%
sizes_b = size(opts.b);
if sizes_b(1) > 1 && sizes_b(2) > 1
    error('Samples vector b should be a column vector.');
end
if sizes_b(2) > 1
    opts.b = opts.b';
end   

%%
if ~isfield(opts, {'tau'})    
    error('The regularization parameter tau is required.');
else
    if opts.tau <= 0, 
        error('The regularization parameter tau, i.e. opts.tau, must be greater than 0.'); 
    end
end

%%
if ~isfield(opts, {'cont_steps'})  
    order_tau = floor(log(abs(opts.tau))./log(10));
    order_mu  = floor(log(abs(opts.mu))./log(10));
    order = min(order_tau,order_mu);
    if order < -1
         opts.cont_steps = -order;  
    else
        opts.cont_steps = 1;  
    end        
else
    if opts.cont_steps <= 0
        error('Continuation steps must be greater than 0.'); 
    end
end

%%
if ~isfield(opts, {'prec_tol'})    
    opts.prec_tol = 1.0e-4;
else
    if opts.prec_tol <= 0
        error('Parameter prec_tol must be positive'); 
    end    
end

%% Built TV matrices.
e          = ones(max(opts.n1,opts.n2),1);
e2         = e;
e2(opts.n2:end) = 0;
J          = spdiags([-e2,e], 0:1,opts.n2,opts.n2);
I          = sparse(1:opts.n1,1:opts.n1,ones(opts.n1,1));
opts.Wt_re      = kron(J,I);  % horizontal differences, sparse matrix
            
e2         = e;
e2(opts.n1:end) = 0;
J          = spdiags([-e2,e], 0:1,opts.n1,opts.n1);
I          = sparse(1:opts.n2,1:opts.n2,ones(opts.n2,1));
opts.Wt_im      = kron(I,J);  % vertical differences, sparse matrix

%%
if ~isfield(opts, {'x0'})  
    opts.x0 = zeros(opts.n,1);
else
    size_x0 = size(opts.x0);
    if size_x0(1) > 1 && size_x0(2) > 1
        error('The argument opts.x0 should be a vector.');
    end
    if size_x0(2) > 1
        opts.x0 = opts.x0';
    end
end

%%
if ~isfield(opts, {'y0'})  
    Wt_re_x = opts.Wt_re*opts.x0;
    Wt_im_x = opts.Wt_im*opts.x0;
    Wtx = Wt_re_x +1i*Wt_im_x;
    
    y_tilde = Wtx;
    y_bar   = min(1./abs(y_tilde),1).*y_tilde;
    y_re    = real(y_bar);
    y_im    = imag(y_bar);
    opts.y0 = y_re + 1i*y_im;
else
    size_y0 = size(opts.y0);
    if size_y0(1) > 1 && size_y0(2) > 1
        error('The argument opts.y0 should be a vector.');
    end
    if size_y0(2) > 1
        opts.y0 = opts.y0';
    end
    if size_y0(1) ~= opts.n
        error('The length of vector opts.y0 must be equal to opts.n1 times opts.n2.');
    end
end

%%
if ~isfield(opts, {'rankupdates'})  
    opts.rankupdates = 6;  
else
    if opts.rankupdates <= 0 || opts.rankupdates > opts.n
        error('The rank updates must be greater than 0 and less or equal to n.'); 
    end
end

if ~isfield(opts, {'PCG_method'})  
    opts.PCG_method = 'tv_pcg';
end